@@ -54,6 +54,7 @@ ScriptImage(cmd, symset)
         };
 
         inccount = 0;
+	mlist = NULL;
         scrStream = (istream *)&scrSource;
 
         load(initial);
@@ -1344,7 +1345,7 @@ noexec:
 		if(initkey == SCRIPT_INDEX_SIZE && initcount)
 			slog.info("compiled %s initializer; %d steps", init->name, initcount);
 		else if(initcount)
-			slog.info("compiled %s initializer; %d steps", init->name, initcount);
+			slog.info("compiled %s; %d steps", init->name, initcount);
 		init->next = index[initkey];
 		index[initkey] = init;
 	}
