@@ -59,6 +59,7 @@
 #define	SCRIPT_EXEC_WRAPPER
 #define	SCRIPT_APPS_WRAPPER
 #define	SCRIPT_RIPPLE_LEVEL 2
+#define	SCRIPT_BINDER_SELECT
 
 #ifndef CCXX_PACKING
 #if defined(__GNUC__)
@@ -625,6 +626,7 @@ protected:
 	
 	virtual void attach(ScriptInterp *interp);
 	virtual void detach(ScriptInterp *interp);
+	virtual bool select(ScriptInterp *interp);
 	virtual bool reload(ScriptCompiler *img);
 	virtual bool control(ScriptImage *img, char **args);
 	virtual void down(void);
